@@ -338,7 +338,7 @@ class rcube_washtml
                             if ($url = $this->wash_uri($match[2])) {
                                 $result .= ' ' . $attr->nodeName . '="' . $match[1]
                                     . '(' . htmlspecialchars($url, ENT_QUOTES, $this->config['charset']) . ')'
-                                    . substr($val, strlen($match[0])) . '"';
+                                    . htmlspecialchars(substr($val, strlen($match[0])), ENT_QUOTES, $this->config['charset']) . '"';
                                 continue;
                             }
                         }
@@ -734,7 +734,8 @@ class rcube_washtml
             // washtml/DOMDocument cannot handle xml namespaces
             '/<html\s[^>]+>/i',
             // washtml/DOMDocument cannot handle xml namespaces
-            '/<\?xml:namespace\s[^>]+>/i',
+            // HTML5 parser cannot handler <?xml
+            '/<\?xml[^>]*>/i',
         );
 
         $html_replace = array(
